@@ -27,6 +27,11 @@ if ($this->GetPreference('block_title','') != '') {
 } else {
     $description_block = '';
 }
+if ($this->GetPreference('html_title','en') != '') {
+    $lang_block = $this->GetPreference('html_title','en');
+} else {
+    $lang_block = '';
+}
 if ($this->GetPreference('content_var_title','') != '') {
     $contentVar = $this->GetPreference('content_var_title','');
     $contentVar = str_replace(' ','', $contentVar);
@@ -63,8 +68,8 @@ if ($checkContent != '') {
     $keywords = strip_tags(str_replace('"','',$keywords));
     $keywords = preg_replace('/{.*}/','',$keywords);
     $keywords = preg_replace(array('/&[^\s]*;/'), '', $keywords);
-    $keywords = htmlentities($keywords, ENT_COMPAT, 'UTF-8');
-    $keywords = utf8_encode(html_entity_decode($keywords));
+    //$keywords = htmlentities($keywords, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
+    //$keywords = utf8_encode(html_entity_decode($keywords)); //Commented out to solve unicode display problems
 }
 
 if ($keywords != '') {
@@ -147,8 +152,8 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
-    $desc = utf8_encode(html_entity_decode($desc));
+    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
+    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
 } elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
     if ($contentVar != '') {
         foreach ($contentVar as $key => $countVar2) {
@@ -163,8 +168,8 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
-    $desc = utf8_encode(html_entity_decode($desc));
+    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
+    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } elseif ($this->GetPreference('auto_title','1') == 1) {
@@ -181,8 +186,8 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
-    $desc = utf8_encode(html_entity_decode($desc));
+    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
+    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } else {
@@ -190,6 +195,17 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
 }
 
 
+///// XML LANGUAGE /////
+$monkey = $this->GetPreference('html_title','en');
+if (preg_match('/{/', $monkey)) {
+    $this->smarty->assign('html_title', $lang_block);
+    $lang_block = str_replace('{$','',$lang_block);
+    $lang_block = str_replace('}','',$lang_block);
+} else {
+    $this->smarty->assign('html_title', $this->GetPreference('html_title','en'));
+}
+
+
 
 ///// SET PREFERENCES /////
 
@@ -205,7 +221,6 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('delimiter_title', $this->GetPreference('delimiter_title','::'));
    $this->smarty->assign('meta_title', $this->GetPreference('meta_title',''));
    $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
-   $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
    $this->smarty->assign('keywords_title', $skipwords);
    $this->smarty->assign('keywords_default', $this->GetPreference('key_default',''));
    $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
@@ -233,11 +248,11 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('bingid_title', $this->GetPreference('bingid_title',''));
    $this->smarty->assign('opendoctype_title', $this->GetPreference('opendoctype_title','0'));
    $this->smarty->assign('doctype_title', $this->GetPreference('doctype_title','-1'));
-   $this->smarty->assign('html_title', $this->GetPreference('html_title','en'));
    $this->smarty->assign('xmlns_title', $this->GetPreference('xmlns_title','0'));
    $this->smarty->assign('dir_title', $this->GetPreference('dir_title','0'));
    $this->smarty->assign('dirchoice_title', $this->GetPreference('dirchoice_title','-1'));
    $this->smarty->assign('lang_title', $this->GetPreference('lang_title','0'));
+   $this->smarty->assign('html_title', $smarty->get_template_vars($lang_block));
    $this->smarty->assign('xmllang_title', $this->GetPreference('xmllang_title','0'));
    $this->smarty->assign('htmlextra_title', $this->GetPreference('htmlextra_title',''));
    $this->smarty->assign('openhtml_title', $this->GetPreference('openhtml_title','0'));
