@@ -66,7 +66,7 @@ $lang['doctype_xhtml1_rdf'] = 'XHTML 1.1 + RDFa';
 $lang['doctype_xhtml_rdf'] = 'XHTML + RDFa';
 $lang['doctype_xhtml_basic_1_0'] = 'XHTML Basic 1.0';
 $lang['doctype_xhtml_basic_1_1'] = 'XHTML Basic 1.1';
-$lang['html_title'] = 'Specify HTML language';
+$lang['html_title'] = 'Specify HTML language (Possible use of smarty variable i.e &#123;$varIable})';
 $lang['htmlextra_title'] = 'Extra HTML tag content';
 $lang['htmlextra_title_help'] = 'Manifest information for example';
 $lang['openhtml_title'] = 'Generate Opening HTML Tag';
@@ -170,7 +170,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.2 26 February 2012. Minor bug fix.</li>
 <li>Version 1.7.3 27 February 2012. Added seperate cms_stylesheet and cms_jquery tabs.</li>
 <li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li>
-<li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li></ul>';
+<li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li>
+<li>Version 1.7.4.1 29 February 2012. Minor bug fix and the addition of smarty use in the language field, useful for mulitlingual sites.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
